@@ -1,4 +1,5 @@
 use proclock_macro::proclock;
+use std::panic::catch_unwind;
 use std::sync::atomic::{AtomicBool, Ordering};
 use std::sync::Arc;
 use std::thread;
@@ -28,11 +29,9 @@ fn nested_calls_to_a_function_with_blocking_macro_annotation_should_block_the_ca
 }
 
 #[test]
-#[should_panic(
-    expected = "Os { code: 11, kind: WouldBlock, message: \"Resource temporarily unavailable\" }"
-)]
 fn nested_calls_to_a_function_with_non_blocking_macro_annotation_should_yield_panic() {
-    non_blocking_lock(|| non_blocking_lock(|| {}));
+    let result = catch_unwind(|| non_blocking_lock(|| non_blocking_lock(|| {})));
+    assert!(result.is_err());
 }
 
 #[proclock(name = "non_block.lock")]
